package cc.fascinated.backend.repository;

import cc.fascinated.backend.model.score.Score;
import org.springframework.data.mongodb.repository.MongoRepository;
import org.springframework.data.mongodb.repository.Query;

import java.util.List;

/**
 * A repository for {@link Score}s.
 */
public interface ScoreRepository extends MongoRepository<Score, String> {

    /**
     * Gets the scores for an account.
     *
     * @param accountId The id of the account.
     * @return The scores for the account.
     */
    @Query("{ 'accountId' : ?0 }")
    List<Score> getScores(String accountId);

    /**
     * Gets the ranked scores for an account.
     *
     * @param accountId The id of the account.
     * @return The ranked scores for the account.
     */
    @Query(value = "{ 'accountId' : ?0, 'pp' : { $gt : 0 } }", sort = "{ 'pp' : -1 }")
    List<Score> getRankedScores(String accountId);

    /**
     * Gets the scores sorted by the newest for an account.
     *
     * @param accountId The id of the account.
     * @return The scores.
     */
    @Query(value = "{ 'accountId' : ?0 }", sort = "{ 'timeSet' : -1 }")
    List<Score> getScoresSortedByNewest(String accountId);

    /**
     * Gets the scores for an account and a leaderboard.
     *
     * @param accountId The id of the account.
     * @param leaderboardId The id of the leaderboard.
     * @return The scores for the leaderboard.
     */
    @Query(value = "{ 'accountId' : ?0, 'leaderboardId' : ?1 }", sort = "{ 'timeSet' : -1 }")
    List<Score> getScoreForLeaderboard(String accountId, String leaderboardId);
}
